#
# spec file for package python-PyWebDAV3-GNUHealth
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%bcond_without  test
Name:           python-PyWebDAV3-GNUHealth
Version:        0.12.0
Release:        3.1
%define ltmsver 0.15
Summary:        WebDAV library for Python - GNU Health port
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Web/Servers
URL:            https://health.gnu.org
Source0:        https://files.pythonhosted.org/packages/source/P/PyWebDAV3-GNUHealth/PyWebDAV3-GNUHealth-%{version}.tar.gz
Source1:        https://notroj.github.io/litmus/litmus-%{ltmsver}.tar.gz

# TODO: send this upstream (where?)
Patch0:         pywebdav-server-configparser.patch
Patch1:         litmus_version.patch

BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module pytest}
BuildRequires:  libxml2-devel
%endif
Conflicts:      python-PyWebDAV3
BuildArch:      noarch
Requires(post): update-alternatives
Requires(postun): update-alternatives

%python_subpackages

%description
This is a Python WebDAV implementation (level 1 and 2) that
features a library for integrating WebDAV server capabilities
into applications.

An example on how to use the library is included. This server
can be run as daemon.

Port from Andrew Leech PyWebDAV3 library to Support GNU Health.

%prep
%autosetup -p1 -n PyWebDAV3-GNUHealth-%{version}

cp %{SOURCE1} test/

%build
%pyproject_wheel

%install
%pyproject_install

%{python_expand chmod a+x %{buildroot}%{$python_sitelib}/pywebdav/server/server.py
sed -i "s|^#!/usr/bin/env python$|#!%{__$python}|" %{buildroot}%{$python_sitelib}/pywebdav/server/server.py
%fdupes %{buildroot}%{$python_sitelib}
$python -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/pywebdav/server/
$python -O -m compileall -d %{$python_sitelib} %{buildroot}%{$python_sitelib}/pywebdav/server/
%fdupes %{buildroot}%{$python_sitelib}/pywebdav/server/
}

%python_clone -a %{buildroot}%{_bindir}/davserver

%if %{with test}
%check
%pytest
%endif

%post
%python_install_alternative davserver

%postun
%python_uninstall_alternative davserver

%files %{python_files}
%license doc/LICENSE
%doc README.rst doc/Changes doc/TODO
%python_alternative %{_bindir}/davserver
%{python_sitelib}/pywebdav
%{python_sitelib}/PyWebDAV3_GNUHealth-%{version}.dist-info

%changelog
* Wed Aug 28 2024 Axel Braun <axel.braun@gmx.de>
- updated litmus to version 0.15
  litmus_version.patch added
* Sun Feb  4 2024 Ben Greiner <code@bnavigator.de>
- Add pywebdav-server-configparser.patch: Replace long deprecated
  SafeConfigParser
* Sat Jul 15 2023 Axel Braun <axel.braun@gmx.de>
- version 0.12.0
  * Include version and README.rst in MANIFEST.in
  * Fix encoding issues in Thunderbird
  * Enforce str - utf8, not Bytes
* Thu Nov 22 2018 Axel Braun <axel.braun@gmx.de>
- vewrsion 0.10.3
  Check for binary type before encoding
* Thu Sep 21 2017 toddrme2178@gmail.com
- Fix summary and description
- Get unit tests working.
- Disable python2 buil. This package is not compatible with python2
* Mon Sep 18 2017 toddrme2178@gmail.com
- Add provides/obsoletes for python-PyWebDav
- Implement update-alternatives for compatibility with
  python-PyWebDAV3
* Thu Sep  7 2017 toddrme2178@gmail.com
- initial version
